@@ -45,6 +45,8 @@ var rollupFuncs = map[string]bool{
 	"scrape_interval":       true,
 	"tmin_over_time":        true,
 	"tmax_over_time":        true,
+	"tfirst_over_time":      true,
+	"tlast_over_time":       true,
 	"share_le_over_time":    true,
 	"share_gt_over_time":    true,
 	"count_le_over_time":    true,
